pub enum ValidationType {
Reject,
Ignore,
Allow,
Require,
}Variants
Reject
Require the claim to be absent and fail if it is present.
Ignore
Ignore the claim.
Allow
If the claim is present, it must be valid.
Require
Require the claim to be present and be valid.