KeyRegistry

Struct KeyRegistry 

pub struct KeyRegistry<K: IsKey> { /* private fields */ }
A collection of Key or PublicKey objects.

Implementations

Source

impl KeyRegistry<PrivateKey>

pub fn private() -> Self

Create a new private key registry.

Source

impl KeyRegistry<PublicKey>

pub fn public() -> Self

Create a new public key registry.

Source

impl KeyRegistry<Key>

pub fn new() -> Self

Create a new key registry that may contain both private and public keys.

Source

impl<K: IsKey> KeyRegistry<K>

pub fn clear(&mut self)

Clear the registry.

pub fn into_keys(self) -> impl Iterator<Item = K>

pub fn add_key(&mut self, key: K)

Add a key to the registry. If the key already exists, it will be replaced. If the key specifies the same kid as another key already added, the new key will replace the old one.

Adding a key, even if it already exists, will make it the active key.

pub fn remove_key(&mut self, key: &K)

Remove a key from the registry by its key.

pub fn remove_kid(&mut self, kid: &str) -> bool

Remove a key from the registry by its kid. Note: O(N).

pub fn len(&self) -> usize

Get the number of keys in the registry.

pub fn is_empty(&self) -> bool

Check if the registry is empty.

pub fn add_from_jwkset(&mut self, jwkset: &str) -> Result<usize, KeyError>

Add keys from a JWKSet.

pub fn add_from_pem(&mut self, pem: &str) -> Result<usize, KeyError>

Add keys from a PEM file.

pub fn add_from_any(&mut self, source: &str) -> Result<usize, KeyError>

Add keys from a source string which can be either a JWK set or a PEM file with 1 or more keys.

pub fn to_pem(&self) -> String

pub fn to_json(&self) -> Result<String, KeyError>

pub fn unsafely_decode_without_validation( &self, token: &str, ) -> Result<HashMap<String, Any>, ValidationError>

Decode a token without validating the signature.

pub fn validate( &self, token: &str, ctx: &ValidationContext, ) -> Result<HashMap<String, Any>, ValidationError>

pub fn sign( &self, claims: HashMap<String, Any>, ctx: &SigningContext, ) -> Result<String, SignatureError>

Source

impl KeyRegistry<PrivateKey>

pub fn can_sign(&self) -> bool

pub fn can_validate(&self) -> bool

pub fn has_private_keys(&self) -> bool

pub fn has_public_keys(&self) -> bool

pub fn has_symmetric_keys(&self) -> bool

Source

impl KeyRegistry<PublicKey>

pub fn can_sign(&self) -> bool

pub fn can_validate(&self) -> bool

pub fn has_public_keys(&self) -> bool

pub fn has_private_keys(&self) -> bool

pub fn has_symmetric_keys(&self) -> bool

Source

impl KeyRegistry<Key>

pub fn can_sign(&self) -> bool

pub fn can_validate(&self) -> bool

pub fn has_private_keys(&self) -> bool

pub fn has_public_keys(&self) -> bool

pub fn has_symmetric_keys(&self) -> bool

pub fn to_pem_public(&self) -> Result<String, KeyError>

Export the registry as a PEM file containing only the public keys. This will fail if the registry contains symmetric keys.

pub fn to_json_public(&self) -> Result<String, KeyError>

Export the registry as a JSON object containing only the public keys. This will fail if the registry contains symmetric keys.